import type { NextRequest } from 'next/server';

import { createOpenAI } from '@ai-sdk/openai';
import { convertToCoreMessages, streamText } from 'ai';
import { NextResponse } from 'next/server';

import { createOllama } from 'ollama-ai-provider';


// export async function POST(req: NextRequest) {
//   const {
//     messages,
//     model = 'llama3.2:latest',
//     system,
//   } = await req.json();

//   const apiKey = key || process.env.OPENAI_API_KEY;

//   if (!apiKey) {
//     return NextResponse.json(
//       { error: 'Missing OpenAI API key.' },
//       { status: 401 }
//     );
//   }

//   const openai = createOpenAI({ apiKey });

//   try {
//     const result = await streamText({
//       maxTokens: 2048,
//       messages: convertToCoreMessages(messages),
//       model: openai(model),
//       system: system,
//     });

//     return result.toDataStreamResponse();
//   } catch {
//     return NextResponse.json(
//       { error: 'Failed to process AI request' },
//       { status: 500 }
//     );
//   }
// }


export async function POST(req: Request) {
  const { messages, model = 'llama3.2:latest' } = await req.json();

  const ollama = createOllama({
    baseURL: 'http://localhost:11434/api'
  });

  try {
    const result = await streamText({
      model: ollama(model),
      messages: messages,
      maxTokens: 2048,
      temperature: 0.7,
    });

    return result.toDataStreamResponse({
      headers: {
        'Content-Type': 'text/event-stream',
        'Cache-Control': 'no-cache',
        'Connection': 'keep-alive',
      }
    });
  } catch (error) {
    return new Response(JSON.stringify({ error: 'Error processing request' }), {
      status: 500,
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }
}